Discover Packages
github.com/nylas/cli
internal
cli
update
package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Jan 30, 2026
License: MIT
Opens a new window with license information.
Imports: 21
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Package update provides CLI self-update functionality.
func CheckForUpdateAsync(currentVersion string )
CheckForUpdateAsync checks for updates in the background and prints a message if available.
This can be called during CLI startup for non-blocking update notifications.
NewUpdateCmd creates the update command.
type Asset struct {
Name string `json:"name"`
Size int64 `json:"size"`
BrowserDownloadURL string `json:"browser_download_url"`
ContentType string `json:"content_type"`
}
Asset represents a release asset (downloadable file).
type Release struct {
TagName string `json:"tag_name"`
Name string `json:"name"`
HTMLURL string `json:"html_url"`
Body string `json:"body"`
Draft bool `json:"draft"`
Prerelease bool `json:"prerelease"`
Assets []Asset `json:"assets"`
}
Release represents a GitHub release.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.